@@ -3,9 +3,9 @@ package jdk.internal.jshell.tool.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "17.0.8.1+1" },
-            { "jdk", "17.0.8.1" },
-            { "release", "17.0.8.1" },
+            { "full", "25.0.1+8-LTS" },
+            { "jdk", "25.0.1" },
+            { "release", "25.0.1" },
         };
     }
 }
