@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -66,7 +66,7 @@ import java.util.ListResourceBundle;
 public class FormatData_jmc extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] metaValue_generic_AmPmMarkers = new String[] {
+        final String[] metaValue_generic_narrow_AmPmMarkers = new String[] {
             "utuko",
             "kyiukonyi",
             "",
@@ -164,7 +164,11 @@ public class FormatData_jmc extends ListResourceBundle {
             "R3",
             "R4",
         };
-        final String[] metaValue_Eras = new String[] {
+        final String[] metaValue_java_time_long_Eras = new String[] {
+            "Kabla ya Kristu",
+            "Baada ya Kristu",
+        };
+        final String[] metaValue_java_time_Eras = new String[] {
             "KK",
             "BK",
         };
@@ -198,24 +202,14 @@ public class FormatData_jmc extends ListResourceBundle {
             "d MMM y GGGG",
             "dd/MM/y G",
         };
-        final String metaValue_generic_DateFormatItem_y = "y";
-        final String metaValue_buddhist_DateFormatItem_Hm = "HH:mm";
-        final String metaValue_buddhist_DateFormatItem_MMMMd = "MMMM d";
-        final String metaValue_buddhist_DateFormatItem_M = "L";
-        final String metaValue_buddhist_DateFormatItem_d = "d";
-        final String metaValue_buddhist_DateFormatItem_MMMd = "MMM d";
-        final String metaValue_buddhist_DateFormatItem_ms = "mm:ss";
-        final String metaValue_buddhist_DateFormatItem_MMM = "LLL";
-        final String metaValue_buddhist_DateFormatItem_Hms = "HH:mm:ss";
         final Object[][] data = new Object[][] {
             { "generic.DayNames", metaValue_generic_DayNames },
             { "generic.DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "generic.DayNarrows", metaValue_generic_DayNarrows },
             { "generic.QuarterNames", metaValue_generic_QuarterNames },
             { "generic.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "generic.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "generic.narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "generic.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "generic.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "generic.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "generic.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.generic.DatePatterns", metaValue_java_time_generic_DatePatterns },
             { "generic.DatePatterns", metaValue_generic_DatePatterns },
@@ -223,7 +217,7 @@ public class FormatData_jmc extends ListResourceBundle {
             { "generic.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "generic.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
             { "generic.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
-            { "generic.DateFormatItem.y", metaValue_generic_DateFormatItem_y },
+            { "generic.DateFormatItem.y", "y" },
             { "generic.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "generic.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
             { "generic.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
@@ -248,17 +242,15 @@ public class FormatData_jmc extends ListResourceBundle {
             { "standalone.QuarterNames", metaValue_generic_QuarterNames },
             { "QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
             { "standalone.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "long.Eras",
-                new String[] {
-                    "Kabla ya Kristu",
-                    "Baada ya Kristu",
-                }
-            },
-            { "Eras", metaValue_Eras },
-            { "narrow.Eras", metaValue_Eras },
+            { "AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "java.time.long.Eras", metaValue_java_time_long_Eras },
+            { "long.Eras", metaValue_java_time_long_Eras },
+            { "java.time.Eras", metaValue_java_time_Eras },
+            { "Eras", metaValue_java_time_Eras },
+            { "java.time.narrow.Eras", metaValue_java_time_Eras },
+            { "narrow.Eras", metaValue_java_time_Eras },
             { "field.era", "Kacha" },
             { "field.year", "Maka" },
             { "field.month", "Mori" },
@@ -296,30 +288,21 @@ public class FormatData_jmc extends ListResourceBundle {
             { "buddhist.DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "buddhist.QuarterNames", metaValue_generic_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "buddhist.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "buddhist.narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "buddhist.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "buddhist.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "buddhist.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_generic_DatePatterns },
             { "buddhist.DatePatterns", metaValue_generic_DatePatterns },
             { "buddhist.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "buddhist.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
-            { "buddhist.DateFormatItem.Hm", metaValue_buddhist_DateFormatItem_Hm },
             { "buddhist.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
-            { "buddhist.DateFormatItem.MMMMd", metaValue_buddhist_DateFormatItem_MMMMd },
-            { "buddhist.DateFormatItem.M", metaValue_buddhist_DateFormatItem_M },
             { "buddhist.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
-            { "buddhist.DateFormatItem.d", metaValue_buddhist_DateFormatItem_d },
-            { "buddhist.DateFormatItem.MMMd", metaValue_buddhist_DateFormatItem_MMMd },
-            { "buddhist.DateFormatItem.y", metaValue_generic_DateFormatItem_y },
             { "buddhist.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "buddhist.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
-            { "buddhist.DateFormatItem.ms", metaValue_buddhist_DateFormatItem_ms },
-            { "buddhist.DateFormatItem.MMM", metaValue_buddhist_DateFormatItem_MMM },
             { "buddhist.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
             { "buddhist.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
             { "buddhist.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "buddhist.DateFormatItem.Hms", metaValue_buddhist_DateFormatItem_Hms },
             { "buddhist.DateFormatItem.yM", metaValue_generic_DateFormatItem_yM },
             { "buddhist.DateFormatItem.yMMMM", metaValue_generic_DateFormatItem_yMMMM },
             { "buddhist.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
@@ -329,29 +312,27 @@ public class FormatData_jmc extends ListResourceBundle {
             { "japanese.DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "japanese.QuarterNames", metaValue_generic_QuarterNames },
             { "japanese.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "japanese.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "japanese.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "japanese.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
+            { "japanese.DatePatterns",
+                new String[] {
+                    "EEEE, d MMMM yyyy GGGG",
+                    "d MMMM yyyy GGGG",
+                    "d MMM y GGGG",
+                    "dd/MM/y G",
+                }
+            },
             { "japanese.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "japanese.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
-            { "japanese.DateFormatItem.Hm", metaValue_buddhist_DateFormatItem_Hm },
             { "japanese.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
-            { "japanese.DateFormatItem.MMMMd", metaValue_buddhist_DateFormatItem_MMMMd },
-            { "japanese.DateFormatItem.M", metaValue_buddhist_DateFormatItem_M },
             { "japanese.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
-            { "japanese.DateFormatItem.d", metaValue_buddhist_DateFormatItem_d },
-            { "japanese.DateFormatItem.MMMd", metaValue_buddhist_DateFormatItem_MMMd },
-            { "japanese.DateFormatItem.y", metaValue_generic_DateFormatItem_y },
             { "japanese.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "japanese.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
-            { "japanese.DateFormatItem.ms", metaValue_buddhist_DateFormatItem_ms },
-            { "japanese.DateFormatItem.MMM", metaValue_buddhist_DateFormatItem_MMM },
             { "japanese.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
             { "japanese.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
             { "japanese.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "japanese.DateFormatItem.Hms", metaValue_buddhist_DateFormatItem_Hms },
             { "japanese.DateFormatItem.yM", metaValue_generic_DateFormatItem_yM },
             { "japanese.DateFormatItem.yMMMM", metaValue_generic_DateFormatItem_yMMMM },
             { "japanese.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
@@ -362,29 +343,19 @@ public class FormatData_jmc extends ListResourceBundle {
             { "roc.DayNarrows", metaValue_generic_DayNarrows },
             { "roc.QuarterNames", metaValue_generic_QuarterNames },
             { "roc.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "roc.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "roc.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "roc.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "roc.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.roc.DatePatterns", metaValue_java_time_generic_DatePatterns },
             { "roc.DatePatterns", metaValue_generic_DatePatterns },
             { "roc.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "roc.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
-            { "roc.DateFormatItem.Hm", metaValue_buddhist_DateFormatItem_Hm },
             { "roc.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
-            { "roc.DateFormatItem.MMMMd", metaValue_buddhist_DateFormatItem_MMMMd },
-            { "roc.DateFormatItem.M", metaValue_buddhist_DateFormatItem_M },
             { "roc.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
-            { "roc.DateFormatItem.d", metaValue_buddhist_DateFormatItem_d },
-            { "roc.DateFormatItem.MMMd", metaValue_buddhist_DateFormatItem_MMMd },
-            { "roc.DateFormatItem.y", metaValue_generic_DateFormatItem_y },
             { "roc.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "roc.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
-            { "roc.DateFormatItem.ms", metaValue_buddhist_DateFormatItem_ms },
-            { "roc.DateFormatItem.MMM", metaValue_buddhist_DateFormatItem_MMM },
             { "roc.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
             { "roc.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
             { "roc.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "roc.DateFormatItem.Hms", metaValue_buddhist_DateFormatItem_Hms },
             { "roc.DateFormatItem.yM", metaValue_generic_DateFormatItem_yM },
             { "roc.DateFormatItem.yMMMM", metaValue_generic_DateFormatItem_yMMMM },
             { "roc.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
@@ -392,71 +363,43 @@ public class FormatData_jmc extends ListResourceBundle {
             { "islamic.DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "islamic.QuarterNames", metaValue_generic_QuarterNames },
             { "islamic.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "islamic.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "islamic.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "islamic.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.islamic.DatePatterns", metaValue_java_time_generic_DatePatterns },
             { "islamic.DatePatterns", metaValue_generic_DatePatterns },
             { "islamic.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "islamic.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
-            { "islamic.DateFormatItem.Hm", metaValue_buddhist_DateFormatItem_Hm },
             { "islamic.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
-            { "islamic.DateFormatItem.MMMMd", metaValue_buddhist_DateFormatItem_MMMMd },
-            { "islamic.DateFormatItem.M", metaValue_buddhist_DateFormatItem_M },
             { "islamic.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
-            { "islamic.DateFormatItem.d", metaValue_buddhist_DateFormatItem_d },
-            { "islamic.DateFormatItem.MMMd", metaValue_buddhist_DateFormatItem_MMMd },
-            { "islamic.DateFormatItem.y", metaValue_generic_DateFormatItem_y },
             { "islamic.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "islamic.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
-            { "islamic.DateFormatItem.ms", metaValue_buddhist_DateFormatItem_ms },
-            { "islamic.DateFormatItem.MMM", metaValue_buddhist_DateFormatItem_MMM },
             { "islamic.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
             { "islamic.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
             { "islamic.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "islamic.DateFormatItem.Hms", metaValue_buddhist_DateFormatItem_Hms },
             { "islamic.DateFormatItem.yM", metaValue_generic_DateFormatItem_yM },
             { "islamic.DateFormatItem.yMMMM", metaValue_generic_DateFormatItem_yMMMM },
             { "islamic.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
             { "islamic-civil.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "islamic-civil.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
-            { "islamic-civil.DateFormatItem.Hm", metaValue_buddhist_DateFormatItem_Hm },
             { "islamic-civil.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
-            { "islamic-civil.DateFormatItem.MMMMd", metaValue_buddhist_DateFormatItem_MMMMd },
-            { "islamic-civil.DateFormatItem.M", metaValue_buddhist_DateFormatItem_M },
             { "islamic-civil.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
-            { "islamic-civil.DateFormatItem.d", metaValue_buddhist_DateFormatItem_d },
-            { "islamic-civil.DateFormatItem.MMMd", metaValue_buddhist_DateFormatItem_MMMd },
-            { "islamic-civil.DateFormatItem.y", metaValue_generic_DateFormatItem_y },
             { "islamic-civil.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "islamic-civil.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
-            { "islamic-civil.DateFormatItem.ms", metaValue_buddhist_DateFormatItem_ms },
-            { "islamic-civil.DateFormatItem.MMM", metaValue_buddhist_DateFormatItem_MMM },
             { "islamic-civil.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
             { "islamic-civil.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
             { "islamic-civil.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "islamic-civil.DateFormatItem.Hms", metaValue_buddhist_DateFormatItem_Hms },
             { "islamic-civil.DateFormatItem.yM", metaValue_generic_DateFormatItem_yM },
             { "islamic-civil.DateFormatItem.yMMMM", metaValue_generic_DateFormatItem_yMMMM },
             { "islamic-civil.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
             { "islamic-umalqura.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "islamic-umalqura.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
-            { "islamic-umalqura.DateFormatItem.Hm", metaValue_buddhist_DateFormatItem_Hm },
             { "islamic-umalqura.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
-            { "islamic-umalqura.DateFormatItem.MMMMd", metaValue_buddhist_DateFormatItem_MMMMd },
-            { "islamic-umalqura.DateFormatItem.M", metaValue_buddhist_DateFormatItem_M },
             { "islamic-umalqura.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
-            { "islamic-umalqura.DateFormatItem.d", metaValue_buddhist_DateFormatItem_d },
-            { "islamic-umalqura.DateFormatItem.MMMd", metaValue_buddhist_DateFormatItem_MMMd },
-            { "islamic-umalqura.DateFormatItem.y", metaValue_generic_DateFormatItem_y },
             { "islamic-umalqura.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "islamic-umalqura.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
-            { "islamic-umalqura.DateFormatItem.ms", metaValue_buddhist_DateFormatItem_ms },
-            { "islamic-umalqura.DateFormatItem.MMM", metaValue_buddhist_DateFormatItem_MMM },
             { "islamic-umalqura.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
             { "islamic-umalqura.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
             { "islamic-umalqura.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "islamic-umalqura.DateFormatItem.Hms", metaValue_buddhist_DateFormatItem_Hms },
             { "islamic-umalqura.DateFormatItem.yM", metaValue_generic_DateFormatItem_yM },
             { "islamic-umalqura.DateFormatItem.yMMMM", metaValue_generic_DateFormatItem_yMMMM },
             { "islamic-umalqura.DateFormatItem.yQQQQ", metaValue_generic_DateFormatItem_yQQQQ },
