@@ -370,9 +370,9 @@ public class LocaleNames_ee extends OpenListResourceBundle {
             { "de", "Germaniagbe" },
             { "dv", "divehgbe" },
             { "dz", "dzongkhagbe" },
-            { "ee", "E\u028begbe" },
+            { "ee", "e\u028begbe" },
             { "el", "grisigbe" },
-            { "en", "Yevugbe" },
+            { "en", "i\u014blisigbe" },
             { "eo", "esperantogbe" },
             { "es", "Spanishgbe" },
             { "et", "estoniagbe" },
@@ -529,7 +529,7 @@ public class LocaleNames_ee extends OpenListResourceBundle {
             { "Knda", "kannadagbe\u014b\u0254\u014bl\u0254" },
             { "Kore", "Koreagbe\u014b\u0254\u014bl\u0254" },
             { "Laoo", "laogbe\u014b\u0254\u014bl\u0254" },
-            { "Latn", "Latingbe\u014b\u0254\u014bl\u0254" },
+            { "Latn", "latingbe\u014b\u0254\u014bl\u0254" },
             { "Mlym", "malayagbe\u014b\u0254\u014bl\u0254" },
             { "Mong", "mongoliagbe\u014b\u0254\u014bl\u0254" },
             { "Mymr", "myanmargbe\u014b\u0254\u014bl\u0254" },
